@@ -5,3 +5,5 @@ from gtoolkit.db.mysql.orm.sqlalchemy.engine import MysqlSQLAlchemyEngine
 from gtoolkit.db.mysql.orm.sqlalchemy.methods import MysqlSQLAlchemyMethods
 from gtoolkit.db.postgresql.orm.sqlalchemy.engine import PostgreSQLAlchemyEngine
 from gtoolkit.db.postgresql.orm.sqlalchemy.methods import PostgreSQLAlchemyMethods
+from gtoolkit.db.postgresql.orm.sqlalchemy.engine import SQLAlchemyEngineBase
+from gtoolkit.db.postgresql.orm.sqlalchemy.methods import SQLAlchemyMethodsBase, BaseModel
