@@ -12,6 +12,7 @@
         Session 在使用 with 时，会丢失方法的提示，所以套了一层 SessionBase 使得能够正常访问，书写更舒服
 """
 from sqlalchemy import create_engine
+from sqlalchemy.engine import Connection
 from sqlalchemy.engine.url import URL
 from sqlalchemy.orm import Session
 
@@ -58,11 +59,19 @@ class SQLAlchemyEngineBase:
         # 创建 engine
         self.engine = create_engine(self.conn_url, **config_default)  # 创建连接
 
-    @property
-    def session(self) -> SessionBase:
+    def session(self, **kwargs) -> SessionBase:
         """
         获取执行的 session
 
         :return:
         """
-        return SessionBase(self.engine)
+        return SessionBase(bind=self.engine, **kwargs)
+
+    def connect(self, close_with_result: bool = False) -> Connection:
+        """
+        原始连接
+
+        :param close_with_result:
+        :return:
+        """
+        return self.engine.connect(close_with_result)
