@@ -17,13 +17,15 @@
         res = method.execute(sql='select * from table', fetchone=True, back_dict=True)
 
     注意：
-        with self.engine.session as session：(自动关闭 session)
+        with self.engine.session() as session：(自动关闭 session)
             with session.begin():   (自动提交回滚捕获错误)
 
         同时使用：
-            with self.engine.session as session, session.begin():
+            with self.engine.session() as session, session.begin():
                 session 会自动关闭
                 session.begin 可以自动捕获错误，自动回滚，自动提交
+
+        如果是 Table 类，那可能不起作用
 """
 import os
 from pathlib import Path
@@ -41,14 +43,20 @@ class SQLAlchemyMethodsBase:
     def __init__(self, engine: SQLAlchemyEngineBase):
         self.engine = engine
 
-    def reverse_table_model(self, path: str, tables: List[str] = None):
+    def reverse_table_model(self, path: str, tables: List[str] = None, commands: str = None):
         """
         逆向表模型
 
         注意：pip install sqlacodegen
 
+        注意，若生成的是 Table 而不是 class 类，有以下 3 种情况
+            1、表无主键
+            2、表是其他表之间的关联表
+            3、使用了 -noclasses 参数
+
         :param path: 最终生成的 models.py 文件路径
         :param tables: 需要逆向的表，默认是所有表
+        :param commands: 其他命令
         :return:
         """
         if Path(path).suffix != '.py':
@@ -58,10 +66,15 @@ class SQLAlchemyMethodsBase:
 
         conn_url = self.engine.conn_url.render_as_string(hide_password=False)  # 将 url 类转换为 url 字符串
 
+        command = f"sqlacodegen {conn_url} > {path}"
+
         if tables:
-            os.system(f"sqlacodegen {conn_url} > {path} --tables {','.join(tables)}")
-        else:
-            os.system(f"sqlacodegen {conn_url} > {path}")
+            command += f" --tables {','.join(tables)}"
+
+        if commands:
+            command += f" {commands}"
+
+        os.system(command)
 
     def insert_one(self, instance: BaseModel):
         """
@@ -70,7 +83,7 @@ class SQLAlchemyMethodsBase:
         :param instance: 模型类
         :return:
         """
-        with self.engine.session as session, session.begin():
+        with self.engine.session() as session, session.begin():
             session.add(instance)
 
     def insert_many(self, instance_list: List[BaseModel]):
@@ -80,7 +93,7 @@ class SQLAlchemyMethodsBase:
         :param instance_list: 模型类列表
         :return:
         """
-        with self.engine.session as session, session.begin():
+        with self.engine.session() as session, session.begin():
             session.add_all(instance_list)
 
     def merge(self, instance, load: bool = True, options=None):
@@ -92,7 +105,7 @@ class SQLAlchemyMethodsBase:
         :param options:
         :return:
         """
-        with self.engine.session as session, session.begin():
+        with self.engine.session() as session, session.begin():
             session.merge(instance, load, options)
 
     def execute(self, sql: str, fetchone: bool = False, fetchmany: int = None, fetchall: bool = False,
@@ -106,7 +119,7 @@ class SQLAlchemyMethodsBase:
         :param back_dict: 以字典形式返回
         :return:
         """
-        with self.engine.session as session, session.begin():
+        with self.engine.session() as session, session.begin():
             result = session.execute(sql, **kwargs)
 
         if fetchone:
@@ -134,7 +147,7 @@ class SQLAlchemyMethodsBase:
         :param instance:
         :return:
         """
-        with self.engine.session as session, session.begin():
+        with self.engine.session() as session, session.begin():
             session.delete(instance)
 
     @staticmethod
@@ -153,21 +166,27 @@ class SQLAlchemyMethodsBase:
         return instance_dict
 
     @staticmethod
-    def _get_update_data(instance_dict: dict, update_keys: List[str]) -> dict:
+    def _get_update_data(instance_dict: dict, update_keys: List[str], exclude_keys: List[str]) -> dict:
         """
         获取更新的数据
 
         :param instance_dict: 数据字典
         :param update_keys: 需要更新的字段
+        :param exclude_keys: 需要排除的字段
         :return:
         """
-        if not update_keys:
-            return instance_dict
-
         update_dict = {}
 
-        for key, value in instance_dict.items():
-            if key in update_keys:
-                update_dict[key] = value
+        if not update_keys:
+            update_dict = instance_dict
+        else:
+            for key, value in instance_dict.items():
+                if key in update_keys:
+                    update_dict[key] = value
+
+        if exclude_keys:
+            for key in exclude_keys:
+                if key in update_dict:
+                    del update_dict[key]
 
         return update_dict
